@@ -210,17 +210,16 @@ def setup_initialcond(data, generators, times):
     if len(times) <= 1:
         return  # for UC,ED no need to set initial status
 
-    t_init = times.initialTime
     if len(data) == 0:
         logging.warning('''No generation initial conditions file found.
             Setting to defaults.''')
         for gen in generators:
-            gen.set_initial_condition(time=t_init)
+            gen.set_initial_condition()
         return
 
     # begin by setting initial condition for all generators to off
     for g in generators:
-        g.set_initial_condition(t_init, status=False, power=0)
+        g.set_initial_condition(status=False, power=0)
 
     names = [g.name for g in generators]
 
@@ -236,7 +235,7 @@ def setup_initialcond(data, generators, times):
     for i, row in data.iterrows():
         g = names.index(row['name'])
         kwds = row[fields_initial].dropna().to_dict()
-        generators[g].set_initial_condition(time=t_init, **kwds)
+        generators[g].set_initial_condition(**kwds)
     return
 
 
@@ -441,17 +440,21 @@ def setup_times(generators_data, loads_data):
             raise NotImplementedError(
                 'wind capacity factor only works with one wind generator')
             
-        max_load = timeseries[filter(lambda col: col.startswith('d'),
-            timeseries.columns)].sum(axis=1).max()
-        capf_current = timeseries[obs_name].max() / max_load
+        all_loads = timeseries[filter(lambda col: col.startswith('d'),
+            timeseries.columns)]
+
+        capf_current = timeseries[obs_name].sum() / all_loads.sum(axis=1).sum()
         
         wind_mult = user_config.wind_capacity_factor / capf_current
         user_config.wind_multiplier = wind_mult
 
+        logging.info('scaling wind from a c.f. of {} to a c.f. of {}'.format(
+            capf_current, user_config.wind_capacity_factor
+            ))
         timeseries[obs_name] *= wind_mult
         if fcst_name:
-            timeseries[fcst_name] *= wind_mult
-
+            timeseries[fcst_name] *= wind_mult        
+        
     return timeseries, times, generators_data, loads_data
 
 
