@@ -14,27 +14,27 @@ except ImportError:
     from ordereddict import OrderedDict
 
 from commonscripts import (update_attributes, gen_time_dataframe, joindir,
-    replace_all, getattrL, elementwiseAdd, writeCSV, transpose, within,
+    replace_all, getattrL, writeCSV, transpose, within, correct_status,
     set_trace)
 from schedule import TimeIndex
 from optimization import value
 from config import user_config
 
-for_publication = True
-
-try:
-    import matplotlib
-    import matplotlib.pyplot as plot
-    do_plotting = True
-    # prettify plots
+def prettify_plots(for_publication=True):
     plot.rc("xtick", direction="out")
     plot.rc("ytick", direction="out")
     plot.rc("ytick", labelsize='small')
     plot.rc("xtick", labelsize='small')
     plot.rc("legend", fancybox=True)
+    plot.rc("font", family="serif")
     if for_publication:
         plot.rc("font", size=16)
-        plot.rc("font", family="serif")
+        
+
+try:
+    import matplotlib
+    import matplotlib.pyplot as plot
+    do_plotting = True
 except ImportError:
     logging.warning("Can't import matplotlib -- skipping plotting.")
     do_plotting = False
@@ -76,12 +76,16 @@ def make_solution(power_system, times, **kwargs):
         SCUC=Solution_SCUC,
         stochastic_UC=Solution_Stochastic_UC
     )
+    if do_plotting:
+        prettify_plots()
     kind = classify_problem(times, power_system)
     return problem_type[kind](power_system, times, **kwargs)
 
 
 def make_multistage_solution(power_system, stage_times, stage_solutions):
     '''Create a multi stage solution'''
+    if do_plotting:
+        prettify_plots()
     if power_system.lines:
         logging.warning('no visualization for multistage SCUC yet')
     klass = MultistageStandalone if getattr(
@@ -143,7 +147,7 @@ class Solution(object):
 
     def _get_outputs(self):
         self.generators_power = self.gen_time_df('power')
-        self.generators_status = _correct_status(self.gen_time_df('status'))
+        self.generators_status = correct_status(self.gen_time_df('status'))
 
     def _get_costs(self):
         self.totalcost_generation = self.gen_time_df('cost', evaluate=True)
@@ -698,7 +702,7 @@ class Solution_Stochastic(Solution):
         else:
             self.generators_power_scenarios = self.stg_panel('power')
             self.generators_status_scenarios = \
-                _correct_status(self.stg_panel('status'))
+                correct_status(self.stg_panel('status'))
             self.expected_status = \
                 self.generators_status_scenarios[self.scenarios[0]]
             self.generators_status = self.expected_status.copy()
@@ -804,13 +808,6 @@ class Solution_Stochastic_UC(Solution_Stochastic):
         self.generators_status.to_csv(full_filename('commitment-status.csv'))
 
 
-def _correct_status(status):
-    # correct for strange solver values returned on resolve
-    status[status > 0.99] = 1
-    status[status < 0.01] = 0
-    return status.astype(int)
-
-
 def _colormap(numcolors, colormapName='gist_rainbow', mincolor=1):
     cm = matplotlib.cm.get_cmap(colormapName)
     return [cm(1. * i / numcolors) for i in range(mincolor, numcolors + mincolor)]
